@@ -403,7 +403,7 @@ class ProxySuiteUnit:
             "auth_corpid": corp_id,
  	        "permanent_code": pernament_code
         })
-        if _ret:
+        if isinstance(_req_result, dict) and "access_token" in _req_result:
             _access_token = _req_result.get("access_token")
             _expires_in = _req_result.get("expires_in")
             # 设置过期时间，使其提前5分钟过期
@@ -456,7 +456,7 @@ class ProxySuiteUnit:
         _tmppath = tempfile.gettempdir()
         if not os.path.isdir(_tmppath):
             raise Exception("template path is invalid")
-        _cache_token_file = os.path.join(_tmppath, f"corp_access_token_{self._corp_id}.bin")
+        _cache_token_file = os.path.join(_tmppath, f"corp_access_token_{self._corp_id}_{self._suite_id}.bin")
         if os.path.isfile(_cache_token_file):
             with open(_cache_token_file, "rb") as f:
                 logger.debug("load access_token from cache file")
@@ -468,7 +468,7 @@ class ProxySuiteUnit:
         if not ret_token or ret_expiretm < int(time.time()):
             # 没有从缓存文件中成功加载token，重新刷新token
             _refresh_data = self._refreshCorpAccessToken(corp_id, pernament_code)
-            logger.debug("get corp_access_token from cache file")
+            logger.debug("get corp_access_token from cache file again!")
             logger.debug(_refresh_data)
             if isinstance(_refresh_data, dict):
                 ret_token = _refresh_data.get("corp_access_token")
@@ -584,6 +584,15 @@ class ProxySuiteUnit:
         _url = f"https://qyapi.weixin.qq.com/cgi-bin/auth/getuserinfo?access_token={self.getAccessToken()}&code={code}"
         logger.debug(_url)
         return self.getRequest(_url, {})
+    
+    def OauthGetAuthUserDetailInfor(self, user_ticket: str):
+        """
+        获取访问用户敏感信息
+        """
+        _url = f"https://qyapi.weixin.qq.com/cgi-bin/auth/getuserdetail?access_token={self.getAccessToken()}"
+        return self.postRequest(_url, {
+            "user_ticket": user_ticket
+        })
 
     def getOauth2RedirectUrl(self, url: str, agentid: str, state: str=None):
         """
@@ -649,7 +658,7 @@ class ProxySuiteUnit:
         """
         获取部门的编号及上下级信息
         """
-        _url = f"https://qyapi.weixin.qq.com/cgi-bin/department/simplelist?access_token={self.getAccessToken()}"
+        _url = f"https://qyapi.weixin.qq.com/cgi-bin/department/simplelist?access_token={self.getCorpAccessToken(self._corp_id, self._secret)}"
         logger.debug(_url)
         if depid:
             _url += f"&id={depid}"
@@ -699,7 +708,7 @@ class ProxySuiteUnit:
         批量获取用户编号
         :param batchsize int 批次大小
         """
-        _url = f"https://qyapi.weixin.qq.com/cgi-bin/user/list_id?access_token={self.getSuiteAccessToken()}"
+        _url = f"https://qyapi.weixin.qq.com/cgi-bin/user/list_id?access_token={self.getCorpAccessToken(self._corp_id, self._secret)}"
         return self.postRequest(_url, {
             "cursor": "",
             "limit": batchsize
