@@ -14,6 +14,7 @@ Change Activity:
 from unittest import TestCase
 import shortuuid
 import datetime
+import xml.etree.ElementTree as ET
 class NormalTest(TestCase):
     def testShortuuid(self):
         datas = []
@@ -23,4 +24,35 @@ class NormalTest(TestCase):
         etm = datetime.datetime.now().strftime("%d:%H:%S")
         print(datas)
         print(len(datas))
-        print(stm, etm)
\ No newline at end of file
+        print(stm, etm)
+
+    def testXmlparse(self):
+        print("")
+        _c = """
+        <?xml version="1.0"?>
+
+<doc>
+
+  <branch name="codingpy.com" hash="1cdf045c">
+
+    text,source
+
+  </branch>
+
+  <branch name="release01" hash="f200013e">
+
+    <sub-branch name="subrelease01">
+
+      xml,sgml
+
+    </sub-branch>
+
+  </branch>
+
+  <branch name="invalid">
+
+  </branch>
+
+</doc>
+        """
+        tree = ET.parse()
\ No newline at end of file
